/*
Zlo volejbalovych majstrovstiev
Autor: Peter Trebaticky

Opis algoritmu :
 Rohy ihriska (ABCD) zoradim tak, aby body A, B, C, D tvorili obdlznik
 (cize AB musi byt kolme na BC), aby usecka AB bola ta vacsia a aby bod A bol
 najspodnejsi, resp. ak je este jeden bod rovnako nizko, najlavejsi. Potom
 zistim suradnice siete EF. Bod E je stred usecky AB a bod F je stred
 usecky CD. Funkcia "vzdialenost" vrati vzdialenost bodu od priamky (danej
 dvoma bodmi).
 Funkcia PATRI zistuje, ci sa bod X nachadza v obdlzniku IJKL.
  Ak sa vzdialenost bodu X od priamky IJ + vzdialenost bodu X od priamky KL
  rovna vzdialenosti priamky IJ od KL (cize velkosti usecky IL) a zaroven
  ak sa vzdialenost bodu X od priamky IL + vzdialenost bodu X od priamky KJ
  rovna vzdialenosti priamky IL od KJ (cize velkosti usecky IJ),
  potom bod X patri obdlzniku IJKL.
 Takymto sposobom zistujem, kde sa nachadza, resp. nenachadza, dany CLOVEK.
*/
#include <stdio.h>
#include <math.h>

#define NOdebug

#define MAX 4823
#define EPS 1e-3

struct BOD{
  float x,y;
};
struct CLOVEK{
  BOD sur;
  char co; // 0-divak, 1-1.druzstvo, 2-2.druzstvo
};

BOD A,B,C,D,E,F;
int PocL, //pocet zucastnenych ludi}
    i,j;
CLOVEK clovek[MAX];

void Vstup(void){
  FILE *f;

#ifdef debug
  f=fopen("volley.in","rt");
#else
  f=stdin;
#endif

  fscanf(f,"%f %f %f %f %f %f %f %f",
    &A.x,&A.y,&B.x,&B.y,&C.x,&C.y,&D.x,&D.y);
  fscanf(f,"%d",&PocL);

  for(int i=0;i<PocL;i++){
    fscanf(f,"%f %f",&clovek[i].sur.x,&clovek[i].sur.y);
  }

#ifdef debug
  fclose(f);
#endif
}

float dlzka(BOD P1,BOD P2){
// Vrati dlzku usecky P1P2
  return sqrt((P1.x-P2.x)*(P1.x-P2.x)+(P1.y-P2.y)*(P1.y-P2.y));
}

float vzdialenost(BOD X,BOD K,BOD L){;
// vrati vzdialenost bodu X od priamky prechadzajucej bodmi K, L
  float s1,s2;
  // suradnice priesecnika priamky KL a kolmice na KL prechadzajucej bodom X

  if(K.x==L.x){
    return fabs(K.x-X.x);
  } else if(K.y==L.y){
      return fabs(K.y-X.y);
    } else{
     s1=((-K.y)+(K.x*(L.y-K.y)/(L.x-K.x))+(X.y)-(X.x*(L.x-K.x)/(K.y-L.y)));
     s1=s1/((K.x-L.x)/(K.y-L.y)+(L.y-K.y)/(L.x-K.x));
     s2=(L.y-K.y)/(L.x-K.x)*s1+K.y-K.x*(L.y-K.y)/(L.x-K.x);
     return sqrt((s1-X.x)*(s1-X.x)+(s2-X.y)*(s2-X.y));
    }
}

int SuKolme(BOD I,BOD J,BOD K,BOD L){
// Ak su priamky IJ a KL na seba kolme, vrati 1. Inak vrati 0.
  float sucin;
  sucin=((J.x-I.x)*(K.x-L.x))+((J.y-I.y)*(K.y-L.y));
  if(sucin==0) return 1; else return 0;
}

int patri(BOD X,BOD I,BOD J,BOD K,BOD L){
// Ak bod X patri stvoruholniku IJKL, vrati 1. Inak vrati 0.
  float v1,v2,d1,d2,pom;
  d1=dlzka(I,L);
  v1=vzdialenost(X,I,J)+vzdialenost(X,K,L);
  d2=dlzka(I,J);
  v2=vzdialenost(X,I,L)+vzdialenost(X,K,J);
  if((fabs(v1-d1)<=EPS)&&(fabs(v2-d2)<=EPS)) return 1; else return 0;
}

void UsporiadajRohy(void){
// Usporiada suradnice rohov ihriska tak,
// ze ABCD bude obdlznik a AB vacsia strana
// Bod A bude patrit prvemu druzstvu

  BOD P;
  if(SuKolme(A,B,B,C)==0){
   P=B;B=C;C=P;
  }
  if(SuKolme(A,B,B,D)==1){
   P=C;C=D;D=P;
  }
  if(dlzka(A,B)<dlzka(B,C)){
   P=B;B=D;D=P;
  }

  P=A;
  if((B.y<P.y)||((B.y==P.y)&&(B.x<P.x)))P=B;
  if((C.y<P.y)||((C.y==P.y)&&(C.x<P.x)))P=C;
  if((D.y<P.y)||((D.y==P.y)&&(D.x<P.x)))P=D;

  if((P.x==B.x)&&(P.y==B.y)){
    P=A;A=B;B=P;
    P=C;C=D;D=P;
  }else
    if((P.x==C.x)&&(P.y==C.y)){
      P=A;A=C;C=P;
      P=B;B=D;D=P;
    }else
      if((P.x==D.x)&&(P.y==D.y)){
        P=A;A=D;D=P;
        P=C;C=B;B=P;
      }
}

void Vystup(void){
  FILE *f;

#ifdef debug
  f=fopen("volley.out","wt");
#else
  f=stdout;
#endif

  fprintf(f,"Players of the first team:\n");
  for(i=0;i<PocL;i++){
    if(clovek[i].co==1)
      fprintf(f,"%d\n",i+1);
  }

  fprintf(f,"Players of the second team:\n");
  for(i=0;i<PocL;i++){
    if(clovek[i].co==2)
      fprintf(f,"%d\n",i+1);
  }

  fprintf(f,"Onlookers:\n");
  for(i=0;i<PocL;i++){
    if(clovek[i].co==0)
      fprintf(f,"%d\n",i+1);
  }

#ifdef debug
  fclose(f);
#endif
}

void main(void){
  Vstup();
  UsporiadajRohy();
  E.x=(A.x+B.x)/2;E.y=(A.y+B.y)/2;
  F.x=(C.x+D.x)/2;F.y=(C.y+D.y)/2;
  for(i=0;i<PocL;i++)
    if(patri(clovek[i].sur,A,E,F,D)==1) clovek[i].co=1;
      else if(patri(clovek[i].sur,E,B,C,F)==1) clovek[i].co=2;
        else clovek[i].co=0;
  Vystup();
}